Kine Slaughter Gothenburg, Sweden February 15th 2004 19 players Alex Ek Deck Name: Ruptura Interior Description: A derange deck that has been in my mind since the new reword on derange. I finally got all the deranges I needed and I put it together and played it on our february tourney here in gothenburg. It took 1GW and 7.5VP in the qualifying rounds in a 19 people tourney, it then took the gw with 3VP's in the final round. Combating Cailean: block/kill, Giovanni: pot/rush, Setite: sb/enticement and Etrius: powerbleed. The idea is to take it easy, try to be friendly even if you put Leandro in play. Play deranges and wait for the right movement. When a majority of the table is turning malk. Then steal the vamps. Minion tap them, Golconda them, Burn them with PTO and prevent them from killing you with obedience. Use all the broken cards you can think of and win. It requires a great deal of thinking and some dealing but it always takes vp and it usually takes gw's too. Crypt (12 cards, min=28, max=44, avg=8.83) ------------------------------------------ 4x Leandro 11 AUS OBF PRE cel dom inner circle Malkavian:2 2x Lucian 10 AUS DOM OBF cel tha justicar Malkavian:1 2x Gilbert Duane 7 AUS DOM OBF prince Malkavian:1 2x Greger Anderssen 7 AUS OBF dom pro prince Malkavian:2 2x Mariel, Lady Thunder 7 DOM OBF aus tha Malkavian:1 Library (90 cards) Master (30) 1x Dominate 1x Elysium: The Arboretum 1x Giant's Blood 3x Golconda: Inner Peace 1x Heidelberg Castle, Germany 2x Information Highway 8x Malkavian Dementia 9x Minion Tap 4x Parthenon, The Action (10) 10x Derange Equipment (1) 1x Ivory Bow Political Action (6) 1x Ancient Influence 1x Dramatic Upheaval 3x Protect Thine Own 1x Rumors of Gehenna Action Modifier (15) 2x Cloak the Gathering 1x Elder Impersonation 2x Faceless Night 5x Forgotten Labyrinth 5x Lost in Crowds Action Modifier/Combat (3) 3x Swallowed by the Night Reaction (25) 9x Obedience 8x Telepathic Misdirection 8x Wake with Evening's Freshness